==> tuia-commercial-center-api-0.0.4-20190613.032719-4-sources.jar: cn/com/duiba/tuia/commercial/center/api/dto/commercial/mission/config/ReqMissionConfigDto.java <==
package cn.com.duiba.tuia.commercial.center.api.dto.commercial.mission.config;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.util.List;

/**
 * [深度互动]任务新增/更新参数
 *
 * @author zhangbaiqiang
 * @date 2019-04-15
 */
@ApiModel
public class ReqMissionConfigDto implements Serializable {
    private static final long serialVersionUID = 4503031965812521798L;

    @ApiModelProperty("深度互动活动类型")
    private Integer bizActivityType;

    @ApiModelProperty("深度互动活动类型描述")
    private String bizActivityTypeDesc;

    @ApiModelProperty("任务id")
    private String id;

    @ApiModelProperty("任务名称")
    private String title;

    @ApiModelProperty("当日任务")
    private List<NormalMissionDto> normalMission;

    @ApiModelProperty("每日任务")
    private List<MissionItemDto> dayMission;

    @ApiModelProperty("连续任务")
    private List<MissionItemDto> seriesMission;

    public Integer getBizActivityType() {
        return bizActivityType;
    }

    public void setBizActivityType(Integer bizActivityType) {
        this.bizActivityType = bizActivityType;
    }

    public String getBizActivityTypeDesc() {
        return bizActivityTypeDesc;
    }

    public void setBizActivityTypeDesc(String bizActivityTypeDesc) {
        this.bizActivityTypeDesc = bizActivityTypeDesc;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public List<NormalMissionDto> getNormalMission() {
        return normalMission;
    }

    public void setNormalMission(List<NormalMissionDto> normalMission) {
        this.normalMission = normalMission;
    }

    public List<MissionItemDto> getDayMission() {
        return dayMission;
    }

    public void setDayMission(List<MissionItemDto> dayMission) {
        this.dayMission = dayMission;
    }

    public List<MissionItemDto> getSeriesMission() {
        return seriesMission;
    }

    public void setSeriesMission(List<MissionItemDto> seriesMission) {
        this.seriesMission = seriesMission;
    }
}

==> tuia-commercial-center-api-1.1.16-sources.jar: cn/com/duiba/tuia/commercial/center/api/dto/commercial/mission/config/ReqMissionConfigDto.java <==
package cn.com.duiba.tuia.commercial.center.api.dto.commercial.mission.config;


import java.io.Serializable;
import java.util.List;

/**
 * [深度互动]任务新增/更新参数
 *
 * @author zhangbaiqiang
 * @date 2019-04-15
 */
public class ReqMissionConfigDto implements Serializable {
    private static final long serialVersionUID = 4503031965812521798L;

    private Integer bizActivityType;

    private String bizActivityTypeDesc;

    private String id;

    private String title;

    private List<NormalMissionDto> normalMission;

    private List<NormalMissionDto> dayMission;

    private List<MissionItemDto> seriesMission;

    public Integer getBizActivityType() {
        return bizActivityType;
    }

    public void setBizActivityType(Integer bizActivityType) {
        this.bizActivityType = bizActivityType;
    }

    public String getBizActivityTypeDesc() {
        return bizActivityTypeDesc;
    }

    public void setBizActivityTypeDesc(String bizActivityTypeDesc) {
        this.bizActivityTypeDesc = bizActivityTypeDesc;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public List<NormalMissionDto> getNormalMission() {
        return normalMission;
    }

    public void setNormalMission(List<NormalMissionDto> normalMission) {
        this.normalMission = normalMission;
    }

    public List<NormalMissionDto> getDayMission() {
        return dayMission;
    }

    public void setDayMission(List<NormalMissionDto> dayMission) {
        this.dayMission = dayMission;
    }

    public List<MissionItemDto> getSeriesMission() {
        return seriesMission;
    }

    public void setSeriesMission(List<MissionItemDto> seriesMission) {
        this.seriesMission = seriesMission;
    }
}
